@@ -33,7 +33,9 @@ from .scidbarray import SciDBArray, SciDBDataShape, ArrayAlias, SDB_IND_TYPE
 from .errors import SHIM_ERROR_DICT, SciDBQueryError, SciDBInvalidSession
 from .utils import broadcastable, _is_query, iter_record, _new_attribute_label, as_list
 from .schema_utils import disambiguate
-from .robust import join, merge, assert_single_attribute
+from .robust import (join, merge, gemm, assert_single_attribute,
+                     boundify, match_chunks,
+                     gesvd, match_chunk_permuted)
 import arithmetic
 
 __all__ = ['SciDBInterface', 'SciDBShimInterface', 'connect']
@@ -706,6 +708,8 @@ class SciDBInterface(object):
         # TODO: make matrix-vector and vector-vector cases more efficient.
         #       Currently they involve creating copies of the arrays, but this
         #       is just a place-holder for a more efficient implementation.
+        A = boundify(A)
+        B = boundify(B)
 
         if A.ndim not in (1, 2) or B.ndim not in (1, 2):
             raise ValueError("dot requires 1 or 2-dimensional arrays")
@@ -735,7 +739,7 @@ class SciDBInterface(object):
         #       an array of zeros?
         # TODO: use spgemm() when the matrices are sparse
         C = self.zeros((A.shape[0], B.shape[1]), dtype=A.dtype)
-        self.afl.gemm(A, B, C).eval(out=C)
+        C = gemm(A, B, C).eval()
 
         if C.shape == output_shape:
             return C
@@ -774,7 +778,7 @@ class SciDBInterface(object):
         ret = []
         for output in ['U', 'S', 'VT']:
             if out_dict[output]:
-                ret.append(self.afl.gesvd(A, "'%s'" % output))
+                ret.append(gesvd(A, "'%s'" % output))
         return tuple(ret)
 
     def from_array(self, A, instance_id=0, **kwargs):
@@ -1077,6 +1081,7 @@ class SciDBInterface(object):
             The remaining arguments are tuples of dimension indices which
             should be joined.
         """
+        B = match_chunk_permuted(B, A, dims).eval()
         dims = [_df(arr, index)
                 for dim in dims
                 for arr, index in zip([A, B], dim)]
@@ -1148,6 +1153,12 @@ class SciDBInterface(object):
                 left_slices = []
                 right_slices = []
 
+                # cross join requires matched chunks
+                left, right = match_chunks(left, right)
+                left_fmt = _af(left.eval(), 0)
+                right_fmt = _af(right.eval(), 0)
+                op = _op(left_fmt, right_fmt)
+
                 for tup in zip(reversed(list(enumerate(left.shape))),
                                reversed(list(enumerate(right.shape)))):
                     (i1, s1), (i2, s2) = tup
