@@ -19,7 +19,7 @@ from . import parse
 from .utils import meshgrid, slice_syntax, _is_query, _new_attribute_label
 from ._py3k_compat import genfromstr, iteritems, csv_reader, string_type
 from .schema_utils import change_axis_schema
-from .robust import join
+from .robust import join, cumulate, reshape, thin
 
 __all__ = ["sdbtype", "SciDBArray", "SciDBDataShape"]
 
@@ -260,8 +260,9 @@ class SciDBDataShape(object):
         if dim_low is None or dim_high is None:
             raise ValueError("Must specify dim_low and dim_high, or shape")
 
-        dim_low = tuple(map(lambda x: None if x == '*' else int(x), dim_low))
-        dim_high = tuple(map(lambda x: None if x == '*' else int(x), dim_high))
+        todim = lambda x: None if x in ('*', None) else int(x)
+        dim_low = tuple(map(todim, dim_low))
+        dim_high = tuple(map(todim, dim_high))
 
         self.dim_low = dim_low
         self.dim_high = dim_high
@@ -314,6 +315,24 @@ class SciDBDataShape(object):
         if len(self.sdbtype.names) != len(set(self.sdbtype.names)):
             warnings.warn("Duplicate attribute names: %s" % self.sdbtype.names)
 
+    def copy(self):
+        """
+        Return a copy of the DataShape
+        """
+        return SciDBDataShape(None,
+                              self.sdbtype,
+                              dim_names=list(self.dim_names),
+                              chunk_size=list(self.chunk_size),
+                              chunk_overlap=list(self.chunk_overlap),
+                              dim_low=list(self.dim_low),
+                              dim_high=list(self.dim_high))
+
+    def __eq__(self, other):
+        return self.schema == other.schema
+
+    def __ne__(self, other):
+        return not self == other
+
     @property
     def ndim(self):
         return len(self.dim_names)
@@ -1142,7 +1161,7 @@ class SciDBArray(object):
         # if thinning is required, then call the thin() command
         if any(i[2] != 1 for i in indices):
             steps = sum([[0, i[2]] for i in indices], [])
-            arr3 = self.afl.thin(arr2, *steps)
+            arr3 = thin(arr2, *steps)
         else:
             arr3 = arr2
 
@@ -1425,7 +1444,7 @@ class SciDBArray(object):
         arr = self.interface.new_array(shape=shape,
                                        dtype=self.sdbtype,
                                        **kwargs)
-        return self.afl.reshape(self, arr).eval(out=arr)
+        return reshape(self, arr).eval(out=arr)
 
     def substitute(self, value):
         """Reshape data into a new array, substituting a default for any nulls.
@@ -1526,8 +1545,11 @@ class SciDBArray(object):
             if len(ind) > 0:
                 idx_args = [self.dim_names[i] for i in ind]
 
-        agg = "{agg}({att})".format(agg=agg, att=self.att(0))
-        return self.afl.aggregate(self, agg, *idx_args)
+        agg = ["{agg}({att})".format(agg=agg, att=a)
+               for a in self.att_names]
+
+        args = agg + idx_args
+        return self.afl.aggregate(self, *args)
 
     def min(self, index=None, scidb_syntax=False):
         """
@@ -1808,7 +1830,7 @@ class SciDBArray(object):
         if isinstance(dimension, int):
             dimension = self.dim_names[dimension]
 
-        return self.afl.cumulate(self, expression, dimension)
+        return cumulate(self, expression, dimension)
 
     def cumsum(self, axis=None):
         """
@@ -1862,7 +1884,7 @@ class SciDBArray(object):
         sums = ["%s(%s) as %s" % (func, att, att)
                 for att in self.att_names]
         sums = ", ".join(sums)
-        return self.afl.cumulate(self, sums, axis)
+        return cumulate(self, sums, axis)
 
     def compress(self, mask, axis=0):
         """
