@@ -5,19 +5,15 @@ import pytest
 from numpy.testing import assert_allclose
 import numpy as np
 
-from .. import connect, histogram
-
-sdb = connect()
+from .. import histogram
+from . import sdb, TestBase, teardown_function
 
 
-class TestHistogram(object):
+class TestHistogram(TestBase):
 
     def setup_method(self, method):
         np.random.seed(42)
 
-    def teardown_method(self, method):
-        sdb.reap()
-
     def test_bad_input(self):
         with pytest.raises(TypeError):
             histogram(1)
