@@ -1,3 +1,6 @@
+# License: Simplified BSD, 2014
+# See LICENSE.txt for more information
+
 import numpy as np
 from numpy.testing import assert_allclose
 import itertools
@@ -17,8 +20,8 @@ def test_broadcastable():
             for shape1 in itertools.permutations(range(1, 4), ndim1):
                 for shape2 in itertools.permutations(range(1, 4), ndim2):
                     try:
-                        b = np.broadcast(np.zeros(shape1),
-                                         np.zeros(shape2))
+                        np.broadcast(np.zeros(shape1),
+                                     np.zeros(shape2))
                         result = True
                     except ValueError:
                         result = False
